@@ -66,19 +66,24 @@ on_exit() {
 }
 trap on_exit EXIT
 
-updated_refs=""
+export OSTREE_REPO=ostree-repo
 
+updated_refs=""
 for element in ${REPO_ELEMENTS}; do
-    ${BST} checkout --hardlinks $element "$checkout/$element"
+    ${BST} checkout --hardlinks $element $checkout/$element
+
     ref=$(ostree refs --repo $checkout/$element)
-    prev_commit=$(ostree rev-parse --repo ostree-repo ${ref} 2>/dev/null || true)
-    test -n "${prev_commit}" && updated_refs="${updated_refs} ${ref}"
-    flatpak build-commit-from --gpg-homedir=ostree-gpg --gpg-sign="$(cat ostree-gpg/default-id)" \
-            --timestamp=NOW \
-            --src-repo="$checkout/$element" --extra-collection-id=org.gnome.GnomeOS ostree-repo $ref
+    commit=$(ostree --repo=$checkout/$element rev-parse $ref)
+    prev_commit=$(ostree rev-parse $ref 2>/dev/null || true)
+
+    ostree pull-local $checkout/$element $commit
+    ostree commit --branch=$ref --tree=ref=$commit --skip-if-unchanged \
+           --gpg-homedir=ostree-gpg --gpg-sign=$(cat ostree-gpg/default-id)
+
+    new_commit=$(ostree rev-parse $ref)
+    test -n "$prev_commit" && test "$new_commit" != "$prev_commit" && updated_refs="$updated_refs $ref"
 done
 
-test -n "${updated_refs}" && ostree static-delta generate --repo ostree-repo ${updated_refs}
-
-flatpak build-update-repo --gpg-homedir=ostree-gpg --gpg-sign="$(cat ostree-gpg/default-id)" \
-        --prune ostree-repo
+ostree prune --refs-only --keep-younger-than="6 months ago"
+test -n "${updated_refs}" && ostree static-delta generate ${updated_refs}
+ostree summary --update --gpg-homedir=ostree-gpg --gpg-sign="$(cat ostree-gpg/default-id)"
